==> pandora-1.6.4.tar.gz: pandora-1.6.4/AUTHORS.md <==
# Credits

Copyright (c) 2024 Centre National d'Etudes Spatiales (CNES).

Pandora is licensed under permissive Apache 2 license (See LICENSE file).
The copyright is kept CNES only for long term maintenance ease.

See CONTRIBUTING.md for more details on Contributor License Agreement.

This file keeps track of authors contributions.

## Development Lead

* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Natalia Jimenez <natalia.jimenez-diaz@csgroup.eu>
* Alice de Bardonnèche-Richard <alice.de-bardonneche-richard@csgroup.eu>
* Marie Leconte <marie.leconte@csgroup.eu>
* Elisa Duz <elisa.duz@csgroup.eu>
* Philippe Mallet-Ladeira <philippe.mallet-ladeira@csgroup.eu>

## Contributors

* Veronique Defonte <veronique.defonte@csgroup.eu>
* Florian Douziech <florian.douziech@csgroup.eu>
* Emmanuel Dubois <emmanuel.dubois@cnes.fr>
* Quentin Fardet <quentin.fardet@csgroup.eu>
* Mannaïg L'Haridon <mannaig.lharidon@csgroup.eu>
* Julien Michel <Julien.Michel@cnes.fr>
* Yoann Steux <yoann.steux@csgroup.eu>
* Mathis Roux <mathis.roux@csgroup.eu>
* David Youssefi <David.Youssefi@cnes.fr>
* Roman Malinowski <roman.malinowski@hds.utc.fr>
* Tommy Calendini <tommy.calendini@cs-soprasteria.com>
* Marian Rassat <marian.rassat@cs-soprasteria.com>

Update here with new contributors.

## Original Developers/Designers/Supporters

* Myriam Cournet <myriam.cournet@cnes.fr>
* Veronique Defonte <veronique.defonte@csgroup.eu>
* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Loïc Dumas <loic.dumas@csgroup.eu>

==> pandora-1.7.1a1.tar.gz: pandora-1.7.1a1/AUTHORS.md <==
# Credits

Copyright (c) 2024 Centre National d'Etudes Spatiales (CNES).

Pandora is licensed under permissive Apache 2 license (See LICENSE file).
The copyright is kept CNES only for long term maintenance ease.

See CONTRIBUTING.md for more details on Contributor License Agreement.

This file keeps track of authors contributions.

## Development Lead

* Alexandre Constantin <alexandre.constatin@cnes.fr>
* Alice de Bardonnèche-Richard <alice.de-bardonneche-richard@cs-soprasteria.com>
* Marie Leconte <marie.leconte@cs-soprasteria.com>
* Elisa Duz <elisa.duz@cs-soprasteria.com>
* Philippe Mallet-Ladeira <philippe.mallet-ladeira@cs-soprasteria.com>

## Contributors
* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Natalia Jimenez <natalia.jimenez-diaz@csgroup.eu>
* Veronique Defonte <veronique.defonte@csgroup.eu>
* Florian Douziech <florian.douziech@cs-soprasteria.com>
* Emmanuel Dubois <emmanuel.dubois@cnes.fr>
* Quentin Fardet <quentin.fardet@cs-soprasteria.com>
* Mannaïg L'Haridon <mannaig.lharidon@csgroup.eu>
* Julien Michel <Julien.Michel@cnes.fr>
* Yoann Steux <yoann.steux@cs-soprasteria.com>
* Mathis Roux <mathis.roux@cs-soprasteria.com>
* David Youssefi <David.Youssefi@cnes.fr>
* Roman Malinowski <roman.malinowski@hds.utc.fr>
* Tommy Calendini <tommy.calendini@cs-soprasteria.com>
* Marian Rassat <marian.rassat@cs-soprasteria.com>

Update here with new contributors.

## Original Developers/Designers/Supporters

* Myriam Cournet <myriam.cournet@cnes.fr>
* Veronique Defonte <veronique.defonte@csgroup.eu>
* Emmanuelle Sarrazin <emmanuelle.sarrazin@cnes.fr>
* Loïc Dumas <loic.dumas@cs-soprasteria.com>
